---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

## Describe the bug
A clear and concise description of what the bug is.

## How to Reproduce
Steps to reproduce the behavior, as minimal as possible.

## Expected behavior
Description of what you expected to happen.

## Actual behavior
Description of what actually happens. If needed may contain logs/outputs.

## Environment (please complete the following information):**
 - OS: [e.g. OSX, Windows]
 - Python version [e.g. 3.7.11]

## Additional context
Add any other context about the problem here.
